@@ -9,6 +9,14 @@ class BaseModel0(models.Model):
     class Meta:
         abstract = True
 
+    @classmethod
+    def model_field_exists(cls, field):
+        try:
+            cls._meta.get_field(field)
+            return True
+        except models.FieldDoesNotExist:
+            return False
+
     @classmethod
     def find_map_by_ids(cls, ids):
         items = list(cls.objects.filter(id__in=ids))
@@ -27,14 +35,26 @@ class BaseModel0(models.Model):
     def get_by_id(cls, id):
         return cls.objects.filter(pk=id).first()
 
+    @classmethod
+    def find_by_id(cls, id):
+        return cls.get_by_id(id)
+
     @classmethod
     def find_many(cls, **kwargs):
         return cls.objects.filter(**kwargs).all()
 
+    @classmethod
+    def find_all(cls):
+        return cls.objects.all()
+
     @classmethod
     def find_one_by(cls, **kwargs):
         return cls.objects.filter(**kwargs).first()
 
+    @classmethod
+    def find_one(cls, **kwargs):
+        return cls.objects.filter(**kwargs).first()
+
 
 class BaseModel(BaseModel0):
     id = models.AutoField(primary_key=True)
